@@ -91,12 +91,15 @@ class OPListEventsException(OPCmdFailedException):
     MSG = "1Passworm 'list events' failed."
 
 
-class OPInvalidDocumentException(_OPAbstractException):
-
+class OPInvalidItemException(_OPAbstractException):
     def __init__(self, msg):
         super().__init__(msg)
 
 
+class OPInvalidDocumentException(OPInvalidItemException):
+    pass
+
+
 class OPNotFoundException(Exception):
     MSG = "1Password cli command not found at path: %s"
 
